residuals.smoots: Extract Model Residuals
Description
Generic function which extracts model residuals from a smoots class
object. Both residuals and its abbreviated form resid can be called.
Usage
# S3 method for smoots
residuals(object, ...)
Value
Residuals extracted from a smoots class object.
Arguments
- object
an object from the smoots class.
- ...
included for consistency with the generic function.